==> archimedes-0.0.4.tar.gz: archimedes-0.0.4/src/constants.h <==
/* constants.h -- This file is part of Archimedes release 0.0.3.
   Archimedes is a simulator for Submicron 2D Silicon/GaAs
   Devices. It implements both the Monte Carlo method and Hybrid MEP model
   for the simulation of the semiclassical Boltzmann equation for both
   electrons and holes. It also includes the quantum effects by means 
   of effective potential method.

   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.  */


// ######################################################
// Created on 5 aug.2004, Siracusa, J.M.Sellier
// Last modif. : 04 mar.2005, Siracusa, J.M.Sellier
// ######################################################

// Universal Physical Constants in M.K.S.C. system

// ######################################################
// ######################################################

// Boltzmann constant (Joule/Kelvin)
 const real KB=1.380658e-23;
// Electron charge in absolute value (Coulomb)
 const real Q=1.60217733e-19;
// Reduced Planck constant (Joule*sec)
 const real HBAR=1.05457266e-34;
// Permittivity of free space (F/m)
 const real EPS0=8.854187817e-12;
// Relative Permittivity of Silicon Carbide 6H
 const real EPSR=11.7;
// Electron Mass (Kg)
 const real M=9.1093897e-31;
// Silicon intrinsic density for room temperature
 const real NI=1.45e16;
// Pi number
 const real PI=3.141592654;
// Silicon Crystal Density (Kg/m^3)
 const real SiRHO=2330.;
// GaAs Crystal Density (Kg/m^3)
 const real GAASRHO=5360.;
// Silicon longitudinal sound velocity (m/sec)
 const real UL=9040.;
// GaAs longitudinal sound velocity (m/sec)
 const real GAASUL=5240.;
// Silicon acoustic deformation potential (Joule)
 const real SiDA=9.*1.60217733e-19;
// GaAs acoustic deformation potential (Joule)
 const real GAASDA=7.*1.60217733e-19;
// electron energy step (eV) for the MC method
 const real DE=0.002;
// mstar coefficient for Silicon
 const real mstarSILICON=0.32;
// mstar coefficient for Si heavy hole
 const real mstarHSILICON=0.57;
// mstar coefficient for GaAs in the GAMMA-valley
 const real mstarGAAS=0.067;
// mstar coefficient for GaAs in the L-valley
 const real mstar2GAAS=0.350;
// mstar coefficient for GaAs heavy hole
 const real mstarHGAAS=0.510;
// non-parabolicity coefficient for GaAs in the GAMMA-valley
 const real alphaGAAS=0.611;
// non-parabolicity coefficient for GaAs in the L-valley
 const real alpha2GAAS=0.242;
// non-parabolicity coefficient for Silicon
 const real alphaSILICON=0.5;
// GaAs optical coupling constant (eV/m)
 double GAASDTK=1.11e11;
// GaAs optical phonon scattering energy (eV)
 double GAASHWO=0.03536;
// Constants for the 6 Silicon non-polar optical phonons 
// (inelastic scattering) 
// Silicon optical coupling constants (eV/m)
 double SiDTK[6]={0.05e11,0.08e11,0.03e11,0.20e11,1.14e11,0.20e11};
// Silicon optical phonon scattering energy (eV)
 double SiHWO[6]={0.0120,0.0185,0.0190,0.0474,0.0612,0.0590};
// Silicon optical phonon Z-factor
 double ZF[6]={1.,1.,4.,4.,1.,4.};
// GaAs energy gap
 real EG_GAAS=0.32;
// GaAs relative dieletric constant
 real EPS_GAAS=12.90;
// GaAs relative dieletric constant
 real EPF_GAAS=10.92;
// Energy minimum of GAMMA-valley
 real E_MIN_GAMMA=0.;
// Energy minimum of L-valley (eV)
 real E_MIN_L=0.29;
// Silicon low field mobility (m^2/(V*sec))
 real MIU0=1400.e-4;
// Silicon saturation velocity (m/sec)
 real VS=1.e5;
// Silicon heavy hole effective mass
 real mstarhole=0.57;
// Silicon heavy hole low field mobility (m^2/(V*sec))
 real MIU0hole=0.0471;
// Silicon heavy hole saturation velocity (m/sec)
 real VShole=1.e5;
// Silicon Schottky contact density (1/m^3)
 real NGATE=3.9e11;
// ######################################################
// ######################################################

==> archimedes-0.0.7.tar.gz: archimedes-0.0.7/src/constants.h <==
/* constants.h -- This file is part of Archimedes release 0.0.7.
   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
   Devices. It implements both the Monte Carlo method and Hybrid MEP model
   for the simulation of the semiclassical Boltzmann equation for both
   electrons and holes. It also includes the quantum effects by means 
   of effective potential method.

   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.  */


// ######################################################
// Created on 5 aug.2004, Siracusa, J.M.Sellier
// Last modif. : 27 dec.2006, Siracusa, J.M.Sellier
// ######################################################

// Universal Physical Constants in M.K.S.C. system

// ######################################################
// ######################################################

// Boltzmann constant (Joule/Kelvin)
 const real KB=1.380658e-23;
// Electron charge in absolute value (Coulomb)
 const real Q=1.60217733e-19;
// Reduced Planck constant (Joule*sec)
 const real HBAR=1.05457266e-34;
// Permittivity of free space (F/m)
 const real EPS0=8.854187817e-12;
// Relative Permittivity of Silicon Carbide 6H
 const real EPSR=11.7;
// Relative Permittivity of Germanium
 const real EPSR_Ge=16.2;
// Electron Mass (Kg)
 const real M=9.1093897e-31;
// Silicon intrinsic density for room temperature
 const real NI=1.45e16;
// Pi number
 const real PI=3.141592654;
// Silicon Crystal Density (Kg/m^3)
 const real SiRHO=2330.;
// GaAs Crystal Density (Kg/m^3)
 const real GAASRHO=5360.;
// Germanium Crystal Density (Kg/m^3)
 const real GeRHO=5320.;
// Silicon longitudinal sound velocity (m/sec)
 const real UL=9040.;
// GaAs longitudinal sound velocity (m/sec)
 const real GAASUL=5240.;
// Germanium longitudinal sound velocity (m/sec)
 const real GeUL=5400.;
// Silicon acoustic deformation potential (Joule)
 const real SiDA=9.*1.60217733e-19;
// GaAs acoustic deformation potential (Joule)
 const real GAASDA=7.*1.60217733e-19;
// Germanium acoustic deformation potential (Joule)
 const real GeDA=9.*1.60217733e-19;
// electron energy step (eV) for the MC method
 const real DE=0.002;
// mstar coefficient for Silicon
 const real mstarSILICON=0.32;
// mstar coefficient for Si heavy hole
 const real mstarHSILICON=0.57;
// mstar coefficient for Germanium (L-valley)
 const real mstarGERMANIUM=0.22;
// mstar coefficient for Germanium heavy hole
 const real mstarHGERMANIUM=0.73;
// mstar coefficient for GaAs in the GAMMA-valley
 const real mstarGAAS=0.067;
// mstar coefficient for GaAs in the L-valley
 const real mstar2GAAS=0.350;
// mstar coefficient for GaAs heavy hole
 const real mstarHGAAS=0.510;
// non-parabolicity coefficient for GaAs in the GAMMA-valley
 const real alphaGAAS=0.611;
// non-parabolicity coefficient for GaAs in the L-valley
 const real alpha2GAAS=0.242;
// non-parabolicity coefficient for Silicon
 const real alphaSILICON=0.5;
// non-parabolicity coefficient for Germanium
 const real alphaGERMANIUM=0.65;
// Germanium optical coupling constant (eV/m) (L-valley)
 double GeDTK=0.055e8;
// Germanium optical phonon scattering energy (eV)
 double GeHWO=0.03704;
// GaAs optical coupling constant (eV/m)
 double GAASDTK=1.11e11;
// GaAs optical phonon scattering energy (eV)
 double GAASHWO=0.03536;
// Constants for the 6 Silicon non-polar optical phonons 
// (inelastic scattering) 
// Silicon optical coupling constants (eV/m)
 double SiDTK[6]={0.05e11,0.08e11,0.03e11,0.20e11,1.14e11,0.20e11};
// Silicon optical phonon scattering energy (eV)
 double SiHWO[6]={0.0120,0.0185,0.0190,0.0474,0.0612,0.0590};
// Silicon optical phonon Z-factor
 double ZF[6]={1.,1.,4.,4.,1.,4.};
// GaAs energy gap
 real EG_GAAS=0.32;
// GaAs relative dieletric constant
 real EPS_GAAS=12.90;
// GaAs relative dieletric constant
 real EPF_GAAS=10.92;
// Energy minimum of GAMMA-valley
 real E_MIN_GAMMA=0.;
// Energy minimum of L-valley (eV)
 real E_MIN_L=0.29;
// Silicon low field mobility (m^2/(V*sec))
 real MIU0=1400.e-4;
// Silicon saturation velocity (m/sec)
 real VS=1.e5;
// Silicon heavy hole effective mass
 real mstarhole=0.57;
// Silicon heavy hole low field mobility (m^2/(V*sec))
 real MIU0hole=0.0471;
// Silicon heavy hole saturation velocity (m/sec)
 real VShole=1.e5;
// Silicon Schottky contact density (1/m^3)
 real NGATE=3.9e11;
// ######################################################
// ######################################################
